@@ -422,6 +422,11 @@ class ExerciseTracker:
                                     session.flush()
                                     session.refresh(rout[num])
                         if reset_only:
+                            #resume
+                            if logMe:
+                                hl=HealthLog(Comments=f"{exercise.Name}:Exercise({i})\t\nResetting! {datetime.now().ctime()}")
+                                session.add(hl)
+                                session.commit()
                             continue
                             #return
                         total_dur=timedelta(seconds=0)
@@ -431,19 +436,28 @@ class ExerciseTracker:
                             for num, i in enumerate(rout):
                                 if completed_reps > total_reps:
                                     completed=ct
+                                    if logMe:
+                                        hl=HealthLog(Comments=f"{exercise.Name}:Exercise({i})\t\nCompleted Stage 2! {datetime.now().ctime()}")
+                                        session.add(hl)
+                                        session.commit()
                                     break
                                 exercise=session.query(Exercise).filter(Exercise.exid==i.exid).first()
                                 exercise.cdt=datetime.now()
-                                if logMe:
-                                    hl=HealthLog(Comments=f"{exercise.Name}:exid:{i}\nstarted! {datetime.now().ctime()}")
-                                    session.add(hl)
-                                    session.commit()
+                                
                                 if exercise.CurrentRep < exercise.Reps:
                                     setattr(exercise,"CurrentRep",getattr(exercise,"CurrentRep")+1)
+                                    if logMe:
+                                        hl=HealthLog(Comments=f"{exercise.Name}:Exercise({i})\t\nstarted! {datetime.now().ctime()}")
+                                        session.add(hl)
+                                        session.commit()
                                 else:
                                     setattr(exercise,"CurrentRep",getattr(exercise,"CurrentRep"))
                                     completed+=1
                                     #completed_reps+=1
+                                    if logMe:
+                                        hl=HealthLog(Comments=f"{exercise.Name}:Exercise({i})\t\nResuming! {datetime.now().ctime()}")
+                                        session.add(hl)
+                                        session.commit()
                                     continue
                                 #os.system("clear")
                                 session.commit()
@@ -473,6 +487,10 @@ class ExerciseTracker:
                                 #print(completed_reps)
                                 completed_reps+=1
                                 if old > completed_reps:
+                                    if logMe:
+                                        hl=HealthLog(Comments=f"{exercise.Name}:Exercise({i})\t\nCompleted Stage 1! {datetime.now().ctime()}")
+                                        session.add(hl)
+                                        session.commit()
                                     continue
                                 for num2, i in enumerate(rout):
                                     rout[num2].Note=json.dumps({'completed':completed_reps,'Total Duration':str(total_dur)})
@@ -497,6 +515,10 @@ class ExerciseTracker:
                         session.add(rd)
                         session.commit()
                         session.refresh(rd)
+                        if logMe:
+                            hl=HealthLog(Comments=f"{exercise.Name}:Exercise({i})\t\nCompleted Stage 3! {datetime.now().ctime()}")
+                            session.add(hl)
+                            session.commit()
                         print(rd)
         except Exception as e:
             print(e)
@@ -565,5 +587,7 @@ class ExerciseTracker:
                 self.removeRoutine()
             elif doWhat.lower() in ['cr','ClearRoutine'.lower()]:
                 self.clearRoutine()
+            elif doWhat.lower() in ['hl','healthlog'.lower()]:
+                HealthLogUi()
             elif doWhat.lower() in "su,summarize".split(","):
                 self.summarize()
\ No newline at end of file
