@@ -436,4 +436,14 @@ Here:
 						'desc':f'A=BH/2',
 						'exec':area_triangle,
 					},
+					f'{uuid1()}':{
+						'cmds':['taxable kombucha',],
+						'desc':f'is kombucha taxable?[taxable=True,non-taxable=False]',
+						'exec':lambda: Taxable.kombucha(None),
+					},
+					f'{uuid1()}':{
+						'cmds':['taxable item',],
+						'desc':f'is item taxable?[taxable=True,non-taxable=False]',
+						'exec':lambda: Taxable.general_taxable(None),
+					},
 }
